Lazy Load Enabled

# Lazy Load Plugin for jQuery

Blog Projects

## Plugin enabled

Images right of the fold are not loaded. When scrolling left they are loaded when needed. Shift-reload to test again. Compare this to page where plugin is disabled or page with gazillion images.

    $("img.lazy").lazyload({
        effect: "fadeIn"
    });

    <img class="lazy" data-original="img/example.jpg" width="765" height="574">